:status: under-construction

SynthDefs
=========

..  self-criticism::

    These docs are still under construction.

- what is a synthdef
- sclang vs supriya implementation

Concepts
--------

- synthdefs
- ugens
- graphs are static
- calculation rates
- multi-channel expansion
- inputs and outputs (and buses)
- parameters and controls

Building
--------

- context managers
- ugen "capture"
- parameters
- multi-channel expansion
- names

Inspection
----------

- printing
- graphing

Lifecycle
---------

- allocation
- freeing

Internals
---------

- UGen metaclass
- ``@ugen`` decorator
- ``param``
